RequestBreadcrumb class

Breadcrumb data for request tracking.

Constructors

RequestBreadcrumb({required BreadcrumbType type, required String message, required String category, required DateTime timestamp, Map<String, dynamic> data = const {}})
const

Properties

category String
Breadcrumb category.
final
data Map<String, dynamic>
Breadcrumb data.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Breadcrumb message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
Timestamp.
final
type BreadcrumbType
Breadcrumb type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts to a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited