invalidate method
Invalidates a specific cache entry by its exact key.
Returns true if the entry existed and was removed.
Implementation
Future<bool> invalidate(String key) async {
final existed = await config.storage.has(key);
if (existed) {
await config.storage.remove(key);
}
return existed;
}